aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org/apache/fop/afp/AFPPaintingState.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/java/org/apache/fop/afp/AFPPaintingState.java')
-rw-r--r--src/java/org/apache/fop/afp/AFPPaintingState.java13
1 files changed, 7 insertions, 6 deletions
diff --git a/src/java/org/apache/fop/afp/AFPPaintingState.java b/src/java/org/apache/fop/afp/AFPPaintingState.java
index 60e4812b9..cb78fb36e 100644
--- a/src/java/org/apache/fop/afp/AFPPaintingState.java
+++ b/src/java/org/apache/fop/afp/AFPPaintingState.java
@@ -21,6 +21,7 @@ package org.apache.fop.afp;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
+import org.apache.fop.afp.fonts.AFPPageFonts;
import org.apache.fop.util.AbstractPaintingState;
/**
@@ -42,7 +43,7 @@ public class AFPPaintingState extends org.apache.fop.util.AbstractPaintingState
private boolean colorImages = false;
/** images are supported in this AFP environment */
- private boolean nativeImages = false;
+ private boolean nativeImagesSupported = false;
/** default value for image depth */
private int bitsPerPixel = 8;
@@ -165,10 +166,10 @@ public class AFPPaintingState extends org.apache.fop.util.AbstractPaintingState
/**
* Sets whether images are natively supported or not in the AFP environment
*
* @param nativeImages true if images are natively supported in this AFP environment
*/
- public void setNativeImages(boolean nativeImages) {
- this.nativeImages = nativeImages;
+ public void setNativeImagesSupported(boolean nativeImagesSupported) {
+ this.nativeImagesSupported = nativeImagesSupported;
}
/**
@@ -176,8 +177,8 @@ public class AFPPaintingState extends org.apache.fop.util.AbstractPaintingState
*
* @return true if images are supported natively in this AFP environment
*/
- public boolean isNativeImages() {
- return this.nativeImages;
+ public boolean isNativeImagesSupported() {
+ return this.nativeImagesSupported;
}
/**
@@ -165,10 +166,10 @@ public class AFPPaintingState extends org.apache.fop.util.AbstractPaintingState
* Sets whether images are natively supported or not in the AFP environment
*
- * @param nativeImages true if images are natively supported in this AFP environment
+ * @param nativeImagesSupported true if images are natively supported in this AFP environment
*/